@@ -353,7 +353,7 @@ def multipoints(geometries, indices=None, out=None, **kwargs):
     ):
         geometries = points(geometries)
     if indices is None:
-        return lib.create_collection(geometries, typ, out=out, **kwargs)
+        return lib.create_collection(geometries, np.intc(typ), out=out, **kwargs)
     else:
         return collections_1d(geometries, indices, typ, out=out)
 
@@ -390,7 +390,7 @@ def multilinestrings(geometries, indices=None, out=None, **kwargs):
         geometries = linestrings(geometries)
 
     if indices is None:
-        return lib.create_collection(geometries, typ, out=out, **kwargs)
+        return lib.create_collection(geometries, np.intc(typ), out=out, **kwargs)
     else:
         return collections_1d(geometries, indices, typ, out=out)
 
@@ -426,7 +426,7 @@ def multipolygons(geometries, indices=None, out=None, **kwargs):
     ):
         geometries = polygons(geometries)
     if indices is None:
-        return lib.create_collection(geometries, typ, out=out, **kwargs)
+        return lib.create_collection(geometries, np.intc(typ), out=out, **kwargs)
     else:
         return collections_1d(geometries, indices, typ, out=out)
 
@@ -457,7 +457,7 @@ def geometrycollections(geometries, indices=None, out=None, **kwargs):
     """
     typ = GeometryType.GEOMETRYCOLLECTION
     if indices is None:
-        return lib.create_collection(geometries, typ, out=out, **kwargs)
+        return lib.create_collection(geometries, np.intc(typ), out=out, **kwargs)
     else:
         return collections_1d(geometries, indices, typ, out=out)
 
@@ -511,7 +511,7 @@ def destroy_prepared(geometry, **kwargs):
     Parameters
     ----------
     geometry : Geometry or array_like
-        Geometries are changed inplace
+        Geometries are changed in-place
     **kwargs
         See :ref:`NumPy ufunc docs <ufuncs.kwargs>` for other keyword arguments.
 
